#ifndef DSHELPER_INCLUDED
#define DSHELPER_INCLUDED

// if you do not have the DirectX SDK installed, set the following define:
// #define NOSDK

#ifndef NOSDK
#include <dsound.h>
#endif



// define correct dll-export/import
#ifdef DSHELPERDLL_EXPORTS
#define DSHELPER_API __declspec(dllexport)
#else
#define DSHELPER_API __declspec(dllimport)
#endif

// init flags:
#define DSH_SHOWDIALOG 1			// not supported, will be ignored
#define DSH_CHOOSEDEVICE 2			// choose default device, even if guid is specified
#define DSH_NOTEXCLUSIVE 4			// use normal cooperative level

// load flags:
#define DSH_FILE 0					// file specified
#define DSH_RESOURCE 1				// resource specified-> not implemented
#define DSH_SEEKFREECHANNEL 2		// seek a free channel instead of using the specified one
#define DSH_STATIC 4				// not implemented
#define DSH_OGG 8					// force ogg format

// play flags:
#define DSH_PLAYONCE 0				// play just once
#define DSH_LOOP 1					// play until other operation (play, stop, unload)
#define DSH_NOREPOSITION 2			// dont change current play position 

// min & max definitions:
#define DSH_MAXCHANNEL 32			// max channels!
#define DSH_VOLUMEMAX 0				// max volume
#define DSH_VOLUMEMIN -10000		// min volume
#define DSH_PANMIN -10000			// min pan (left speaker-> full volume, right speaker-> silent)
#define DSH_PANMAX 10000			// max pan (other way!)
#define DSH_FREQUENCYMIN 100		// min frequency
#define DSH_FREQUENCYMAX 100000		// max frequency

// return values (except dsh_GetDirectSound())
#define DSHRES_FALSE 0
#define DSHRES_TRUE 1
#define DSHRES_OK 0
#define DSHRES_GENERALERROR -1		// general error
#define DSHRES_CANTCREATEDS -5		// DirectSound-object could not be created
#define DSHRES_CANTSETCOOP -2		// cooperative level could not be set
#define DSHRES_CANTCREATEBUFFER -3	// buffer could not be created
#define DSHRES_NOTINIT -4			// dsh_Init() has not been called yet	
#define DSHRES_NOTFREE -6			// channel is not free
#define DSHRES_NOWAVE -7			// file is not a wave file
#define DSHRES_WRONGPARAM -8		// wrong parameter
#define DSHRES_NOOGG -9				// not an ogg file

typedef int CHANNELID;



// general functions:
DSHELPER_API int __stdcall dsh_Init(LPGUID lpGuid, HWND hwnd, INT flags);
DSHELPER_API void __stdcall dsh_Unload(void);
#ifndef NOSDK
DSHELPER_API LPDIRECTSOUND8 __stdcall dsh_GetDirectSound();
DSHELPER_API int __stdcall dsh_GetCaps(DSCAPS* lpCaps);
#else
DSHELPER_API void* __stdcall dsh_GetDirectSound();
DSHELPER_API int __stdcall dsh_GetCaps(void* lpCaps);
#endif

// channel functions:
DSHELPER_API int __stdcall dsh_ChannelLoad(char* lpszResource, CHANNELID channel, INT flags);
DSHELPER_API int __stdcall dsh_ChannelPlay(CHANNELID channel, INT flags);
DSHELPER_API int __stdcall dsh_ChannelStop(CHANNELID channel, INT flags);
DSHELPER_API int __stdcall dsh_ChannelUnload(CHANNELID channel);

DSHELPER_API int __stdcall dsh_ChannelSetVolume(CHANNELID channel, long Volume);
DSHELPER_API int __stdcall dsh_ChannelGetVolume(CHANNELID channel, long* Volume);
DSHELPER_API int __stdcall dsh_ChannelSetPosition(CHANNELID channel, DWORD dwPosition);
DSHELPER_API int __stdcall dsh_ChannelGetPosition(CHANNELID channel, DWORD* dwPosition);
DSHELPER_API int __stdcall dsh_ChannelGetFrequency(CHANNELID channel, LPDWORD lpdwFrequency);
DSHELPER_API int __stdcall dsh_ChannelSetFrequency(CHANNELID channel, DWORD dwFrequency);
DSHELPER_API int __stdcall dsh_ChannelSetPan(CHANNELID channel, long lPan);
DSHELPER_API int __stdcall dsh_ChannelGetPan(CHANNELID channel, long* lPan);
DSHELPER_API int __stdcall dsh_ChannelIsPlaying(CHANNELID channel);
DSHELPER_API int __stdcall dsh_ChannelIsLooping(CHANNELID channel);

#ifndef NOSDK
DSHELPER_API int __stdcall dsh_ChannelGetBuffer(CHANNELID channel, LPDIRECTSOUNDBUFFER8* lpdsb);
DSHELPER_API int __stdcall dsh_ChannelGetFormat(CHANNELID channel, WAVEFORMATEX* lpWaveFormatEx);
#else
DSHELPER_API int __stdcall dsh_ChannelGetBuffer(CHANNELID channel, void* lpdsb);
DSHELPER_API int __stdcall dsh_ChannelGetFormat(CHANNELID channel, void* lpWaveFormatEx);
#endif

#endif